diff --git a/applications/serial_lte_modem/overlay-native_tls.conf b/applications/serial_lte_modem/overlay-native_tls.conf
index c312b9bb2..4004d8007 100644
--- a/applications/serial_lte_modem/overlay-native_tls.conf
+++ b/applications/serial_lte_modem/overlay-native_tls.conf
@@ -24,7 +24,7 @@ CONFIG_MBEDTLS_ENABLE_HEAP=y
 # and CONFIG_MBEDTLS_HEAP_SIZE to 36864
 CONFIG_MBEDTLS_SSL_IN_CONTENT_LEN=5120
 CONFIG_MBEDTLS_SSL_OUT_CONTENT_LEN=4096
-CONFIG_MBEDTLS_HEAP_SIZE=36864
+CONFIG_MBEDTLS_HEAP_SIZE=38656
 CONFIG_MBEDTLS_SSL_SERVER_NAME_INDICATION=y
 #Cipher Suite disable
 CONFIG_MBEDTLS_CTR_DRBG_C=n
diff --git a/applications/serial_lte_modem/src/mqtt_c/slm_at_mqtt.c b/applications/serial_lte_modem/src/mqtt_c/slm_at_mqtt.c
index aa7c91f3d..e83b9fbea 100644
--- a/applications/serial_lte_modem/src/mqtt_c/slm_at_mqtt.c
+++ b/applications/serial_lte_modem/src/mqtt_c/slm_at_mqtt.c
@@ -261,6 +261,13 @@ static void mqtt_thread_fn(void *arg1, void *arg2, void *arg3)
 		}
 	}
 
+#if defined(CONFIG_SLM_NATIVE_TLS)
+	if (ctx.sec_tag != INVALID_SEC_TAG) {
+		(void)slm_tls_unloadcrdl(ctx.sec_tag);
+		ctx.sec_tag = INVALID_SEC_TAG;
+	}
+#endif
+
 	LOG_INF("MQTT thread terminated");
 }
 
@@ -328,6 +335,9 @@ static void client_init(void)
 		struct mqtt_sec_config *tls_config;
 
 		tls_config = &(client.transport).tls.config;
+#if defined(CONFIG_SLM_NATIVE_TLS)
+		tls_config->set_native_tls = true;
+#endif
 		tls_config->peer_verify   = TLS_PEER_VERIFY_REQUIRED;
 		tls_config->cipher_list   = NULL;
 		tls_config->cipher_count  = 0;
@@ -359,9 +369,25 @@ static int do_mqtt_connect(void)
 
 	/* Connect to MQTT broker */
 	client_init();
+
+#if defined(CONFIG_SLM_NATIVE_TLS)
+	err = slm_tls_loadcrdl(ctx.sec_tag);
+	if (err < 0) {
+		LOG_ERR("Fail to load credential: %d", err);
+		return -EAGAIN;
+	}
+#endif
+
 	err = mqtt_connect(&client);
 	if (err != 0) {
 		LOG_ERR("ERROR: mqtt_connect %d", err);
+#if defined(CONFIG_SLM_NATIVE_TLS)
+		if (ctx.sec_tag != INVALID_SEC_TAG) {
+			(void)slm_tls_unloadcrdl(ctx.sec_tag);
+			ctx.sec_tag = INVALID_SEC_TAG;
+		}
+#endif
+
 		return err;
 	}
 
@@ -388,6 +414,13 @@ static int do_mqtt_disconnect(void)
 		return err;
 	}
 
+#if defined(CONFIG_SLM_NATIVE_TLS)
+	if (ctx.sec_tag != INVALID_SEC_TAG) {
+		(void)slm_tls_unloadcrdl(ctx.sec_tag);
+		ctx.sec_tag = INVALID_SEC_TAG;
+	}
+#endif
+
 	if (k_thread_join(&mqtt_thread, K_SECONDS(CONFIG_MQTT_KEEPALIVE)) != 0) {
 		LOG_WRN("Wait for thread terminate failed");
 	}
diff --git a/applications/serial_lte_modem/src/slm_native_tls.c b/applications/serial_lte_modem/src/slm_native_tls.c
index b14a68d2f..3dc7a5573 100644
--- a/applications/serial_lte_modem/src/slm_native_tls.c
+++ b/applications/serial_lte_modem/src/slm_native_tls.c
@@ -10,7 +10,7 @@
 LOG_MODULE_REGISTER(slm_tls, CONFIG_SLM_LOG_LEVEL);
 
 /* max buffer length to load credential */
-#define MAX_CRDL_LEN		4096
+#define MAX_CRDL_LEN		4352
 
 /* pointer to credential buffer */
 static uint8_t *crdl;
